@@ -79,7 +79,13 @@ class UnitOfWork(object):
 
     @tracked_operation
     def track_inserts(self, key, target):
+        """
+        Tracks object insert operations. Whenever object is inserted it is
+        added to this UnitOfWork's internal operations dictionary.
+        """
         if key in self.operations:
+            # If the object is deleted and then inserted within the same
+            # transaction we are actually dealing with an update.
             self.operations[key]['target'] = target
             self.operations[key]['operation_type'] = Operation.UPDATE
         else:
@@ -91,7 +97,7 @@ class UnitOfWork(object):
     @tracked_operation
     def track_updates(self, key, target):
         """
-        Tracks object update operations. Whenever object is deleted it is
+        Tracks object update operations. Whenever object is updated it is
         added to this UnitOfWork's internal operations dictionary.
         """
         self.operations[key] = {
@@ -137,6 +143,11 @@ class UnitOfWork(object):
             )
 
     def create_association_versions(self, session):
+        """
+        Creates association table history records for given session.
+
+        :param session: SQLAlchemy session object
+        """
         for stmt in self.pending_statements:
             stmt = stmt.values(transaction_id=self.current_transaction_id)
             session.execute(stmt)
@@ -302,9 +313,9 @@ class UnitOfWork(object):
 
         op = None
 
-        if statement.startswith('INSERT INTO '):
+        if context.isinsert:
             op = Operation.INSERT
-        elif statement.startswith('DELETE FROM '):
+        elif context.isdelete:
             op = Operation.DELETE
 
         if op is not None:
